@@ -4,7 +4,8 @@ import json
 import random
 
 from gemd.entity.attribute import Condition, Parameter, Property, PropertyAndConditions
-from gemd.entity.bounds import IntegerBounds, RealBounds, CategoricalBounds, CompositionBounds
+from gemd.entity.bounds import IntegerBounds, RealBounds, CategoricalBounds, CompositionBounds, \
+    MolecularStructureBounds
 from gemd.entity.object import ProcessSpec, ProcessRun, MaterialSpec, MaterialRun, \
     MeasurementSpec, MeasurementRun, IngredientSpec, IngredientRun
 from gemd.entity.template import ProcessTemplate, MaterialTemplate, MeasurementTemplate, \
@@ -12,7 +13,8 @@ from gemd.entity.template import ProcessTemplate, MaterialTemplate, MeasurementT
 from gemd.entity.value import NominalInteger, UniformInteger, \
     NominalReal, NormalReal, UniformReal, \
     NominalCategorical, DiscreteCategorical, \
-    NominalComposition, EmpiricalFormula
+    NominalComposition, EmpiricalFormula, \
+    Smiles, InChI
 from gemd.enumeration.origin import Origin
 
 from gemd.entity.util import complete_material_history, make_instance
@@ -113,6 +115,11 @@ def make_cake_templates():
         description="The chemical formula of a material",
         bounds=CompositionBounds(components=EmpiricalFormula.all_elements())
     )
+    tmpl["Molecular Structure"] = PropertyTemplate(
+        name="Molecular Structure",
+        description="The molecular structure of the material",
+        bounds=MolecularStructureBounds()
+    )
 
     # Objects
     tmpl["Baking in an oven"] = ProcessTemplate(
@@ -165,7 +172,8 @@ def make_cake_templates():
         name="Formulaic Material",
         description="A material with chemical characterization",
         properties=[
-            tmpl["Chemical Formula"]
+            tmpl["Chemical Formula"],
+            tmpl["Molecular Structure"]
         ]
     )
     tmpl["Icing"] = ProcessTemplate(name="Icing",
@@ -431,7 +439,12 @@ def make_cake_spec(tmpl=None):
         ],
         notes='Plain old NaCl',
         properties=[
-            PropertyAndConditions(Property(name='Formula', value=EmpiricalFormula("NaCl")))
+            PropertyAndConditions(Property(name='Formula', value=EmpiricalFormula("NaCl"))),
+            PropertyAndConditions(
+                Property(name='InChI',
+                         value=InChI("InChI=1S/ClH.Na/h1H;/q;+1/p-1"),
+                         template=tmpl["Molecular Structure"])
+            )
         ]
     )
     IngredientSpec(
@@ -456,7 +469,13 @@ def make_cake_spec(tmpl=None):
         ],
         notes='Sugar',
         properties=[
-            PropertyAndConditions(Property(name="Formula", value=EmpiricalFormula("C12H22O11")))
+            PropertyAndConditions(Property(name="Formula", value=EmpiricalFormula("C12H22O11"))),
+            PropertyAndConditions(
+                Property(name='SMILES',
+                         value=Smiles("C(C1C(C(C(C(O1)OC2(C(C(C(O2)CO)O)O)CO)O)O)O)O"),
+                         template=tmpl["Molecular Structure"]
+                         )
+            )
         ]
     )
     IngredientSpec(
@@ -670,9 +689,10 @@ def make_cake(seed=None, tmpl=None, cake_spec=None):
                                std=0.05 * item.spec.absolute_quantity.nominal,
                                units=item.spec.absolute_quantity.units)
             if item.spec.volume_fraction is not None:
+                # The only element here is dry mix, and it's almost entirely flour
                 item.volume_fraction = \
-                    NormalReal(mean=fuzz * item.spec.volume_fraction.nominal,
-                               std=0.05 * item.spec.volume_fraction.nominal,
+                    NormalReal(mean=0.01 * (fuzz - 0.5) + item.spec.volume_fraction.nominal,
+                               std=0.005,
                                units=item.spec.volume_fraction.units)
             if item.spec.mass_fraction is not None:
                 item.mass_fraction = \
